﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

#nullable disable

using System;
using Microsoft.CodeAnalysis.SignatureHelp;

namespace Microsoft.CodeAnalysis.Editor
{
    internal class SignatureHelpItemEventArgs(SignatureHelpItem signatureHelpItem) : EventArgs
    {
        public SignatureHelpItem SignatureHelpItem { get; } = signatureHelpItem;
    }
}
